@@ -1,5 +1,4 @@
 if __name__ == "__main__":
     from .installer import main
 
-    retval = main()
-    exit(retval)
+    main()
